@@ -96,6 +96,7 @@ public class JSonParser extends Parser {
 				scrpt = attributeValue.getAsString();
 				attributes.set(Attributes.MAIN_SCRIPT_NAME, scrpt);
 			}
+			
 			else if(attributeName.equals(Attributes.JSON_EXECUTION_TIME))
 			{
 				// R puts : in the timestamp value, but we can't use that in a directory name on Windows.
@@ -130,15 +131,18 @@ public class JSonParser extends Parser {
 			}
 		}
 		
+		ArrayList<ScriptInfo> sourcedScriptInfo = new ArrayList<ScriptInfo>() ;
+		
+		// Add the main script
+		sourcedScriptInfo.add(new ScriptInfo (scrpt, timestamp));
+		
 		// parse source script information, if any
 		if( sourcedScripts == null )
 			return;
 		
-		ArrayList<ScriptInfo> sourcedScriptInfo = new ArrayList<ScriptInfo>() ;
-		
 		while( sourcedScripts.hasNext() && ssTimestamps != null && ssTimestamps.hasNext())
 		{
-			String filepath = scriptDir + "/" + sourcedScripts.next().getAsString() ;
+			String filepath = sourcedScripts.next().getAsString() ;
 			String timestamp = ssTimestamps.next().getAsString() ;
 			
 			sourcedScriptInfo.add( new ScriptInfo(filepath, timestamp) ) ;
@@ -311,7 +315,7 @@ public class JSonParser extends Parser {
 				// If we are loading from a local file, we need to get the full path
 				// to the file.  URL nodes that lack :// are saved copies of
 				// webpages.  URLs that start with -> are actually socket connections.
-				if(type.equals("File") || type.equals("Snapshot") || 
+				if(type.equals("File") || type.equals("Snapshot") || type.equals("StandardOutputSnapshot") || 
 						(type.equals("URL") && value.indexOf("://") == -1 && value.indexOf("->") == -1)){
 					if (builder != null) {
 						File relative = new File(builder.getSourceDDGDirectory(), value);
